@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Protocol::ACME - Interface to the Let's Encrypt ACME API
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -1041,7 +1041,15 @@ sub _create_jws_internal
 sub _decode_json
 {
   my $ref = shift;
-  return JSON->new->allow_nonref->decode($ref);
+
+  my $json = "";
+
+  eval
+  {
+    $json = JSON->new->allow_nonref->decode($ref);
+  };
+
+  return $json;
 }
 
 sub _encode_json
@@ -1118,7 +1126,7 @@ copy of the full license at:
 L<http://www.perlfoundation.org/artistic_license_2_0>
 
 Any use, modification, and distribution of the Standard or Modified
-Version 0.15
+Version 0.16
 distributing the Package, you accept this license. Do not use, modify,
 or distribute the Package, if you do not accept this license.
 
